# SearchSource: Europe PMC

Note: This document is currently under development. It will contain the following elements.

- description
- coverage (disciplines, types of work)
- supported (details): run_search (including updates), load,  prep (including get_masterdata)

[Europe PMC](https://europepmc.org/)

License: [may contain copyrighted material, unless stated otherwise](https://europepmc.org/Copyright)

## Add the search source

```
colrev search -a colrev.europe_pmc -p "https://europepmc.org/search?query=fitbit%20AND%20gamification%20AND%20RCT%20AND%20diabetes%20mellitus"
```

## Links
